package MetaCPAN::Role;
$MetaCPAN::Role::VERSION = '0.05';
# ABSTRACT: Collection of roles useful to MetaCPAN project

=head1 NAME

  MetaCPAN::Role - a collection of roles useful to MetaCPAN project

=head1 DESCRIPTION

Probably not useful to you unless you are developing either
L<https://metacpan.org> or L<https://fastapi.metacpan.org>.

These roles are shared between the MetaCPAN projects, the code base
of which can be found at L<https://github.com/metacpan/>.

=cut

1;